@@ -43,6 +43,7 @@ class Hx():
         pywinauto.clipboard.EmptyClipboard()
         cang_df = pd.read_csv(StringIO(s),dtype={'证券代码': object,'可用余额':int},usecols=[0,1,2,3,4,5,6,7,8,9,10])
         cang_df.drop(cang_df[cang_df['可用余额'] == 0].index, inplace=True)
+        cang_df=cang_df.round(2)
         return cang_df
     #用最新价格更新持仓
     def updata_cang(self,cang_df):
@@ -54,6 +55,8 @@ class Hx():
         cang_df['市价']=temp_list
         cang_df['成本值']=cang_df['成本价']*cang_df['股票余额']
         cang_df['市值']=cang_df['市价']*cang_df['股票余额']
+        cang_df['盈亏']=cang_df['市值']-cang_df['成本值']
+        cang_df['盈亏(%)']=round((cang_df['市值']-cang_df['成本值'])/cang_df['成本值']*100,2)  #round((data['price']-data['close'])/data['close']*100,2)
         cang_df=cang_df.round(2)
         return cang_df
     #获取资金
